"use strict";

exports.__esModule = true;
exports.default = _default;

var _universalEnv = require("universal-env");

var _isCdnImage = _interopRequireDefault(require("./isCdnImage"));

var _isOSSImage = _interopRequireDefault(require("./isOSSImage"));

var _removeScheme = _interopRequireDefault(require("./removeScheme"));

var _replaceDomain = _interopRequireDefault(require("./replaceDomain"));

var _scaling = _interopRequireDefault(require("./scaling"));

var _webp = _interopRequireDefault(require("./webp"));

var _compress = _interopRequireDefault(require("./compress"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var REG_IMG_SUFFIX = /_(\d+x\d+|cy\d+i\d+|sum|m|b)?(xz|xc)?((?:q\d+)?(?:s\d+)?)(\.jpg)?(_\.webp)?$/i;
/*
TODO
缩放剪裁(xz) _100x100xz.jpg @100h_100w_1e
非缩放剪裁(xc) _100x100xc.jpg  @100-50-0-0a
*/

/**
 *
 * @param {String} uri
 * @param {Object} config
 *    scalingWidth
 *    webp
 *    compressSuffix
 *    removeScheme
 *    replaceDomain
 * @returns {String} newUrl
 */

function _default(uri, config) {
  var scalingWidth = config.scalingWidth,
      webp = config.webp,
      compressSuffix = config.compressSuffix,
      quality = config.quality,
      acutance = config.acutance,
      removeScheme = config.removeScheme,
      replaceDomain = config.replaceDomain,
      ignoreGif = config.ignoreGif,
      ignorePng = config.ignorePng;
  var newUrl = uri;

  if (typeof uri === 'string') {
    var ret = (0, _isCdnImage.default)(uri); // is cdn image

    if (ret) {
      var isOSSImg = (0, _isOSSImage.default)(uri);
      var host = ret[1];
      var path = ret[2];
      var suffixRet = path.match(REG_IMG_SUFFIX) || [];
      var notGif = !/\.gif($|\?)/i.test(path) || !ignoreGif;
      var notPng = !/\.png($|\?)/i.test(path) || !ignorePng;
      var scalingSuffix = suffixRet[1] || '';

      if (!_universalEnv.isNode && scalingWidth && notGif) {
        scalingSuffix = (0, _scaling.default)(scalingWidth, isOSSImg) || scalingSuffix;
      } // webp


      var webpSuffix = suffixRet[5] || '';

      if (webp && notGif) {
        webpSuffix = (0, _webp.default)(isOSSImg) || webpSuffix;
      }

      var _compressSuffix = suffixRet[3] || '';

      if ((compressSuffix || quality || acutance) && notGif && notPng) {
        _compressSuffix = (0, _compress.default)(compressSuffix, quality, acutance, isOSSImg) || _compressSuffix;
      }

      var cut = scalingSuffix ? suffixRet[2] || '' : '';
      var suffix = scalingSuffix || _compressSuffix ? suffixRet[4] || '.jpg' : '';
      var prev = scalingSuffix || _compressSuffix ? '_' : '';

      if (isOSSImg) {
        if (prev == '_') {
          prev = '@';
        }

        if (uri.split('@')[1]) {
          prev = '';
        }
      }

      if (notGif) {
        if (suffixRet[0] !== '_.jpg') {
          newUrl = newUrl.replace(suffixRet[0], '');
        }

        if (isOSSImg) {
          newUrl += prev + scalingSuffix + cut + _compressSuffix + webpSuffix;
        } else {
          newUrl += prev + scalingSuffix + cut + _compressSuffix + suffix + webpSuffix;
        }

        if (removeScheme) {
          newUrl = (0, _removeScheme.default)(newUrl);
        }
      }

      if (replaceDomain) {
        newUrl = (0, _replaceDomain.default)(newUrl, host);
      }
    }
  }

  return newUrl;
}