"use strict";

exports.__esModule = true;
exports.default = void 0;

var _rax = require("rax");

var _raxView = _interopRequireDefault(require("rax-view"));

var _raxImage = _interopRequireDefault(require("rax-image"));

var _universalEnv = require("universal-env");

var _universalDevice = require("universal-device");

var _index = _interopRequireDefault(require("./optimizer/index"));

var _webp = require("./webp");

var _formatStyle = _interopRequireDefault(require("./formatStyle"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var isSupportJPG = false;
var isSupportPNG = false; // Can not judge whether support webp in node env

if (!_universalEnv.isNode) {
  (0, _webp.isSupport)(function (_isSupportJPG) {
    isSupportJPG = _isSupportJPG;
  });
  (0, _webp.isSupport)(function (_isSupportPNG) {
    isSupportPNG = _isSupportPNG;
  }, 'alpha');
}
/**
 * @param  {String|[String]} suffix
 * @return {[String]}        [description]
 */


function parseSuffix(suffix) {
  var result = [];
  var ret = [];

  if (typeof suffix === 'string') {
    ret = suffix.split(',');
  }

  if (Array.isArray(suffix)) {
    ret = suffix;
  }

  if (ret && ret[0]) {
    result[0] = ret[0];
  }

  if (ret && ret[1]) {
    result[1] = ret[1];
  }

  return result;
}
/**
 * @param  {String|Array} suffix
 * @return {[type]}
 */


function getQualitySuffix(highQuality, suffix) {
  var _suffix = parseSuffix(suffix);

  return highQuality ? _suffix[0] : _suffix[1];
}

var Picture = (0, _rax.forwardRef)(function (props, ref) {
  var children = props.children,
      className = props.className,
      _props$style = props.style,
      style = _props$style === void 0 ? {} : _props$style,
      resizeMode = props.resizeMode,
      width = props.width,
      height = props.height,
      _props$placeholder = props.placeholder,
      placeholder = _props$placeholder === void 0 ? 'data:image/gif;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAADUlEQVQImWNgYGBgAAAABQABh6FO1AAAAABJRU5ErkJggg==' : _props$placeholder,
      _props$source = props.source,
      source = _props$source === void 0 ? {
    uri: ''
  } : _props$source,
      _props$autoRemoveSche = props.autoRemoveScheme,
      autoRemoveScheme = _props$autoRemoveSche === void 0 ? true : _props$autoRemoveSche,
      _props$autoReplaceDom = props.autoReplaceDomain,
      autoReplaceDomain = _props$autoReplaceDom === void 0 ? true : _props$autoReplaceDom,
      _props$autoScaling = props.autoScaling,
      autoScaling = _props$autoScaling === void 0 ? true : _props$autoScaling,
      _props$autoWebp = props.autoWebp,
      autoWebp = _props$autoWebp === void 0 ? true : _props$autoWebp,
      _props$ignoreGif = props.ignoreGif,
      ignoreGif = _props$ignoreGif === void 0 ? true : _props$ignoreGif,
      _props$autoCompress = props.autoCompress,
      autoCompress = _props$autoCompress === void 0 ? true : _props$autoCompress,
      _props$highQuality = props.highQuality,
      highQuality = _props$highQuality === void 0 ? true : _props$highQuality,
      _props$compressSuffix = props.compressSuffix,
      compressSuffix = _props$compressSuffix === void 0 ? ['Q75', 'Q50'] : _props$compressSuffix,
      _props$defaultHeight = props.defaultHeight,
      defaultHeight = _props$defaultHeight === void 0 ? '750rpx' : _props$defaultHeight,
      _props$lazyload = props.lazyload,
      lazyload = _props$lazyload === void 0 ? false : _props$lazyload,
      _props$autoPixelRatio = props.autoPixelRatio,
      autoPixelRatio = _props$autoPixelRatio === void 0 ? true : _props$autoPixelRatio;
  var uri = source.uri;
  var nativeProps = Object.assign({}, props);

  var _useState = (0, _rax.useState)(false),
      visible = _useState[0],
      setVisible = _useState[1];

  var formatedStyle = (0, _formatStyle.default)(style);
  var sWidth = formatedStyle.width,
      // style width of picture
  sHeight = formatedStyle.height; // style width of picture
  // according to the original height and width of the picture

  if (!sHeight && sWidth && width && height) {
    var pScaling = width / (typeof sWidth === 'string' ? parseInt(sWidth, 10) : sWidth);
    sHeight = parseInt(height / pScaling + '', 10);
  }

  var newStyle = Object.assign({
    height: sHeight
  }, style);

  if (uri) {
    if (!_universalEnv.isNode && autoPixelRatio && _universalDevice.devicePixelRatio > 1) {
      // devicePixelRatio >= 2
      if (typeof sWidth === 'string') {
        if (sWidth.indexOf('rpx') > -1) {
          sWidth = parseInt(sWidth.split('rpx')[0]) * 2 + 'rpx';
        } else if (sWidth.indexOf('rem') > -1) {
          sWidth = parseInt(sWidth.split('rem')[0]) * 2 + 'rem';
        }
      }
    }

    uri = (0, _index.default)(uri, {
      ignoreGif: ignoreGif,
      ignorePng: true,
      removeScheme: autoRemoveScheme,
      replaceDomain: autoReplaceDomain,
      scalingWidth: autoScaling ? sWidth : 0,
      webp: autoWebp && isSupportJPG && isSupportPNG,
      compressSuffix: autoCompress ? getQualitySuffix(highQuality, compressSuffix) : ''
    });
  }

  if (resizeMode) {
    newStyle.resizeMode = resizeMode;
  }

  var url = placeholder;

  if (lazyload) {
    nativeProps.onAppear = function () {
      return setVisible(true);
    };

    if (visible) {
      url = uri;
    }
  } else {
    url = uri;
  }

  if (children) {
    return (0, _rax.createElement)(_raxView.default, _extends({}, nativeProps, {
      className: className,
      style: Object.assign(Object.assign({}, newStyle), {
        backgroundImage: 'url(' + url + ')',
        backgroundSize: resizeMode || 'cover',
        backgroundRepeat: 'no-repeat',
        backgroundPosition: resizeMode === 'cover' || resizeMode === 'contain' ? 'center' : null,
        height: newStyle.height ? newStyle.height : defaultHeight
      }),
      "data-once": true
    }), children);
  } else {
    return (0, _rax.createElement)(_raxImage.default, _extends({}, nativeProps, {
      ref: ref,
      className: className,
      style: newStyle,
      "data-once": true,
      source: {
        uri: url
      }
    }));
  }
});
Picture.displayName = 'Picture';
var _default = Picture;
exports.default = _default;